/*
* Capture Fox - Firefox Extension For Screen Capturing and Voice Recording
* Author: Zafer Gurel
*
* Config.js 
* This javascript file is included in config.xul. It includes methods to config.xul UI elements use.
*
* Modifications
* - Value of a selectem item can be obtained by instance.value in FF 3 but not in FF2! Use instance.selectedItem.value! (zg 12 Sep 08)
*/

var cfmObj; // CaptureFoxMovie object created in overlay.js
var deviceArray = null;
var showMicList = false;
var micList;
var micBox;
var fileUrl;
var filePath;

function getMicDeviceId() {
	return micList.selectedItem.value;
}

function _Config_init(e) {
	cfmObj = window.arguments[0];

	var paneName = window.arguments[1] ? window.arguments[1]  : "settings"; // default pane is settings

	if(!cfmObj) {alert("Initialization error"); self.close();return;} //can not be localized because the localization object is cfmObj.sb
	
	switch(paneName) {
		case "settings":
			initializeSettings();
			break;
		case "result":
			fileUrl = window.arguments[2];
			filePath = window.arguments[3];
			initializeResult();
			break;
	}
	openPane(paneName);

}

function initializeResult() {
}
function initializeSettings() {
	var rgCaptureArea = document.getElementById("rgCaptureArea");
	rgCaptureArea.selectedIndex = cfmObj.configParams.captureArea -1;
	document.getElementById("lblSetRegion").style.display = (cfmObj.configParams.captureArea == 3) ? "block" : "none";
	
	var rgQuality = document.getElementById("rgQuality");
	rgQuality.selectedIndex = (cfmObj.configParams.quality == 30) ? 0 : ((cfmObj.configParams.quality == 60) ? 1 : 2);
	
	var rgAudioCodec = document.getElementById("rgAudioCodec");
    rgAudioCodec.selectedIndex = (cfmObj.configParams.compressSound == 0) ? 0 : 1; // wav or mp3
    
	micBox = document.getElementById("hbMic");
	var chkRecordSound = document.getElementById("chkRecordSound");
	micList = document.getElementById("rgMic");

	var rgCodec = document.getElementById("rgCodec");
	rgCodec.selectedIndex = cfmObj.configParams.compressVideo;

	var ddlFPS = document.getElementById("ddlFPS");
	ddlFPS.selectedIndex = parseInt(cfmObj.configParams.fps) - 1 ;
		
	try {
		deviceArray = cfmObj.getMicrophoneDevices();
	} catch(e) {
		//do nothing
	}
	if(!deviceArray) {
		chkRecordSound.checked = false;
		chkRecordSound.disabled = true;
		chkRecordSound.label = cfmObj.sb.getString("strNoMicAttached");
		micBox.style.display = "none";
	}
	else {
		chkRecordSound.checked = cfmObj.configParams.recordSound;
		
		var micCounter = 0;
		for(var i=0;i<deviceArray.length;i++) { 
			if(deviceArray[i].length > 0) {
				var el = micList.appendItem(deviceArray[i],i); // XULElement is appended. label and value
				++micCounter;
			}
		}
		if(micCounter == 1) { // if there is one mic., hide the mic. list otherwise show it
			showMicList = false;
			micBox.style.display = "none";
			micList.selectedIndex = 0; //getItemAtIndex did not work on FF 2. (zg)
		} else {
			showMicList = true;
		}
		micList.selectedIndex = cfmObj.configParams.micDeviceId;
    }
    
    document.getElementById("lblOutputFolder").value = cfmObj.configParams.outputFolder.path;
    document.getElementById("txtOutputFileName").value = cfmObj.configParams.outputFileName;
    document.getElementById("txtDelay").value = cfmObj.configParams.delay;
    document.getElementById("chkStopCaptureOnFocus").checked = cfmObj.configParams.stopCaptureOnFocus;
    document.getElementById("chkMinimizeOnStart").checked = cfmObj.configParams.minimizeOnStart;
    document.getElementById("chkAllowAutoStart").checked = cfmObj.configParams.allowAutoStart;
    
    if(cfmObj.configParams.screenX) {
        //alert(cfmObj.configParams.pageX + " " + cfmObj.configParams.pageY + " " + cfmObj.configParams.captureRegionWidth + " " + cfmObj.configParams.captureRegionWidth);
        
        var x1, y1, x2, y2, w, h;
        x1 = cfmObj.configParams.pageX;
        x2 = cfmObj.configParams.pageX + cfmObj.configParams.captureRegionWidth;
        y1 = cfmObj.configParams.pageY;
        y2 = cfmObj.configParams.pageY + cfmObj.configParams.captureRegionHeight;
        w = cfmObj.configParams.captureRegionWidth;
        h = cfmObj.configParams.captureRegionHeight;
        document.getElementById("lblSetRegion").value = cfmObj.sb.getString("strRegionCoordinatesSet").replace("#w", w).replace("#h", h);
    }
    document.getElementById("hbStopOnFocus").style.display = cfmObj.configParams.minimizeOnStart ? "" : "none";
}
function toggleStopOnFocus() {
    var o = document.getElementById("hbStopOnFocus");
    o.style.display = (o.style.display == "none") ? "" : "none";
    document.getElementById("chkStopCaptureOnFocus").checked = (o.style.display == "none") ? false : true;
}

function checkParameters() {
    var txtFile = document.getElementById("txtOutputFileName");
    if(txtFile.value.replace(/\t|\\|\/|:|\*|\?|\"|\<|\>/,"").length == 0) {
	    alert(cfmObj.sb.getString("strEnterAValidFileName"));
	    txtFile.focus();
	    return false;
	}
	var txtDelay = document.getElementById("txtDelay");
    if(!/[\d]+/.test(txtDelay.value)) {
        alert(cfmObj.sb.getString("strEnterANumberForDelay"));
	    txtDelay.focus();
	    return false;
	}
	return true;
}

function setParameters() {
    // assign parameters and close the dialog
	cfmObj.configParams.fps = parseInt(document.getElementById("ddlFPS").selectedItem.value);
	cfmObj.configParams.quality=parseInt(document.getElementById("rgQuality").selectedItem.value); // jpeg quality
	cfmObj.configParams.recordSound = document.getElementById("chkRecordSound").checked ? 1 : 0;
	cfmObj.configParams.deviceId = cfmObj.configParams.recordSound ? parseInt(document.getElementById("rgMic").value) : 0; // mic device id
	cfmObj.configParams.captureArea = parseInt(document.getElementById("rgCaptureArea").selectedItem.value); // capture area, 1: whole screen 2: firefox window note:radioGroup.value works in FF3 but not in FF2. that may be the problem that is faced using ff portable
	cfmObj.configParams.compressSound = parseInt(document.getElementById("rgAudioCodec").selectedItem.value);
	cfmObj.configParams.compressVideo = parseInt(document.getElementById("rgCodec").selectedItem.value);
	cfmObj.configParams.outputFileName = document.getElementById("txtOutputFileName").value;
	cfmObj.configParams.delay = parseInt(document.getElementById("txtDelay").value);
	cfmObj.configParams.stopCaptureOnFocus = document.getElementById("chkStopCaptureOnFocus").checked ? 1 : 0;
	cfmObj.configParams.minimizeOnStart = document.getElementById("chkMinimizeOnStart").checked ? 1 : 0;
	cfmObj.configParams.allowAutoStart = document.getElementById("chkAllowAutoStart").checked ? 1 : 0;
}
function btnStart_OnCommand() {
	if(!cfmObj.initialized || !checkParameters()) return;
	setParameters();
	cfmObj.configParams.command= "start";
	self.close();
}

function btnSave_OnCommand() {
    if (!cfmObj.initialized || !checkParameters()) return;
    setParameters();
    cfmObj.configParams.command = "savepreferences";
    self.close();
}

function btnResult_Save_OnCommand() {
	if(opener) opener.saveURL(fileUrl, null, null, false, false, null);
}

function btnResult_Open_OnCommand() {
	if(opener) opener.open(fileUrl);
}

function btnResult_StartAgain_OnCommand() {
	cfmObj.configParams.command = "startagain";
	self.close();
}

function btnResult_PostVideo_OnCommand() {
    var o = this.configParams;
    window.openDialog('chrome://capturefox/content/postvideo.xul','cfmPost','chrome,modal,centerscreen,scrollbars=yes,resizable=yes', cfmObj.configParams.outputFolder.path + "\\" + cfmObj.configParams.outputFileName + ".avi");
	//this.handleConfigCommand();
	
}
function selectOutputFolder () {
    var nsIFilePicker = Components.interfaces.nsIFilePicker;
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
    fp.init(window, cfmObj.sb.getString("strSelectOutputDir") , nsIFilePicker.modeGetFolder);
    var res = fp.show();
    if (res == nsIFilePicker.returnOK){
        cfmObj.configParams.outputFolder = fp.file;
        document.getElementById("lblOutputFolder").value = fp.file.path;        
    }
}

window.addEventListener("load", function(e) {  _Config_init(e); }, false); 

var panes = ["settings","result"]; // these are the ids of the vbox elements (pane) in config.xul

function openPane(name) {
	for(var i=0; i<panes.length;i++) {
		var pane = document.getElementById("pane_" + panes[i]);
		pane.style.display= (panes[i] != name) ? "none" : "";
	}
}

function openHelp() {
    cfmObj.openHelp();
}

function openGeoAds() {
	var ww = Components.classes['@mozilla.org/embedcomp/window-watcher;1'].getService(Components.interfaces.nsIWindowWatcher); 
	var win = ww.openWindow(null, 'chrome://capturefox/content/geoads.xul', 'geoadsoptions', 'chrome,titlebar,toolbar,centerscreen,alwaysRaised,width=425,height=425,dialog=yes', null);
}

function dialog_OnCancel() {
    if (cfmObj.divMarker) cfmObj.showHideMarker(false);
    self.close();
}