/*
* Capture Fox - Firefox Extension For Screen Capturing and Voice Recording
* Author: Zafer Gurel
*
* Overlay.js 
* This is the core javascript code of the extension. The UI communicates with the XPI extension
* through the CaptureFox object which is an instance of the CCaptureFox class.
*
*/

/*
* CCaptureFox : the class that contains the main logic of the extension. 
* On load event, an instance of this class (CaptureFox) is created and it is used across
* all of the XUL windows (config.xul, overlay.xul). The XPI component is initialized in onLoad method
* of the object which is called with the onload event of the window.
*/
function CCaptureFox () {
  
  this.xtt = null; /*timer text*/
  this.xib = null; /*image button control*/
  this.initialized=false;
  this.sb={}; // string bundle
  this.screenCapturer = null,
  this.counter  =  0;
  this.fileCounter = 0;
  this.bCaptureStarted = false;
  this.prefs;
  this.outputFolder; // nsIFile object
  this.addonPath; // addon install path
  
  this.initialScreenX = null;
  this.initialScreenY = null;
  
  this.defaultTitle = "";
  this.isSetTitleToTime = false;
// possible values for configParams.command: start, cancel 
  this.configParams = {command: null, fps:2, quality:60, recordSound:1,micDeviceId:0, captureArea:1};
	this.onLoad = function(e) {
	    if(this.initialized) {
			return; // already initialized
		}
		
		this.sb = document.getElementById("CaptureFox_stringbundle");
		this.xtt = document.getElementById("CaptureFox_statusbar2");
		this.xib = document.getElementById("CaptureFox_ImageButton");
		try {
		  this.prefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService);
		  this.prefs = this.prefs.getBranch("extensions.capturefoxmovie@advancity.net.");
		  this.configParams.quality			= this.prefs.getIntPref("videoQuality");
		  this.configParams.captureArea		= this.prefs.getIntPref("videoCaptureArea");
		  this.configParams.fps 			= this.prefs.getIntPref("videoFPS");
		  this.configParams.recordSound 		= this.prefs.getIntPref("recordSound");
		  this.configParams.micDeviceId 		= this.prefs.getIntPref("micDeviceId");
          this.configParams.compressSound 		= this.prefs.getIntPref("compressSound");
          this.configParams.compressVideo 		= this.prefs.getIntPref("compressVideo");
          this.configParams.delay 		= this.prefs.getIntPref("delay");
          this.configParams.stopCaptureOnFocus 		= this.prefs.getIntPref("stopCaptureOnFocus");
          this.configParams.minimizeOnStart = this.prefs.getIntPref("minimizeOnStart");
          this.configParams.allowAutoStart = this.prefs.getIntPref("allowAutoStart");
          this.configParams.screenX = null;
          this.configParams.screenY = null;
          this.configParams.captureRegionWidth = null;
          this.configParams.captureRegionHeight = null;
          this.configParams.pageX = null;
          this.configParams.pageY = null;
          
          
          // get outputfile name from the preferences, like capturefox. So, the output file is named like capturefox.avi.
          this.configParams.outputFileName 		= this.prefs.getCharPref("outputFileName");
          var tempFolder = this.getDir("TmpD");
          
          // initialize outputFolder object, get the last selected outputfolder from the preferences
          // if it's empty or not a valid directory, set it to temporary directory
          if(this.prefs.getCharPref("outputFolder") != "") this.configParams.outputFolder = this.getDir(this.prefs.getCharPref("outputFolder"));
          if(!this.configParams.outputFolder) this.configParams.outputFolder = tempFolder;

		  var da;//device array
		  try {
			da = this.getMicrophoneDevices();
	  	  } catch(e) {
			;//do nothing
		  }
	      if(da || da.length > 0) {
		    if(da.length-1>this.configParams.micDeviceId) this.configParams.micDeviceId=0; // in case of an invalid mic. device configuration
	      } else {
		    this.configParams.recordSound = 0;
	      }
	    } catch(ex) {
		    ; //use default params
	    }

        // initialization code
        try {
            const cid = "@advancity.net/capturefoxmovie;1";
            this.screenCapturer = Components.classes[cid].createInstance();
            this.screenCapturer = this.screenCapturer.QueryInterface(Components.interfaces.ICaptureFox); 
            this.initialized = true;
        }
        catch (err) { 
            alert(this.sb.getString("strInitError"));
            this.initialized = false;
        }
		  
        var extensionId = "capturefoxmovie@advancity.net"; // the extension's id from install.rdf
        Components.utils.import("resource://gre/modules/AddonManager.jsm");
        AddonManager.getAddonByID(extensionId, function(addon) {
          CaptureFox.addonPath = addon.getResourceURI("").QueryInterface(Components.interfaces.nsIFileURL).file.path;
        });

		var timer = Components.classes["@mozilla.org/timer;1"].createInstance(Components.interfaces.nsITimer)
		timer.initWithCallback({notify:geoAds.doGeoadsSetup},1000,timer.TYPE_ONE_SHOT);
		
		this.setObservers();
		
        /* ff 3 and below */
        //var em = Components.classes["@mozilla.org/extensions/manager;1"].
        //         getService(Components.interfaces.nsIExtensionManager);
        // the path may use forward slash ("/") as the delimiter
        // returns nsIFile for the extension's install.rdf
        //var file = em.getInstallLocation(MY_ID).getItemFile(MY_ID, "");
        setTimeout(this.commandController, 250, this);
  };
  
  this.commandHistory = {};
  
  this.commandController = function(owner) {
    //possible
    if(!content) return;
    if(!owner.configParams.allowAutoStart) return;
    var command = "";
    var commandId = "";
    
    if(content.location.hash.indexOf("#cf_cmd") == 0) {
        command = content.location.hash.split(":")[1];
    } else if(content.document.getElementById("cf_cmd")) {
        var cfObj = content.document.getElementById("cf_cmd");
        if(cfObj.value) {
            command = cfObj.value;
        } else if(cfObj.innerHTML) {
            command = cfObj.innerHTML;
        }
    }
    
    if(command.length > 0 && command.indexOf("|") > -1) {
        var tmp = command;
        command = tmp.split("|")[0];
        commandId = tmp.split("|")[1];
        
        if(commandId.length > 0 && owner.commandHistory["comm_" + commandId] == null) {
            owner.commandHistory["comm_" + commandId] = command;
            switch(command) {
                case "start":
                    owner.openSettingsWindow();
                    break;
                case "quickstart":
                    owner.quickStartCapture();
                    break;
                case "stop":
                    owner.stopCapture(false);
                    break;
                case "quickstop":
                    CaptureFox.stopCapture(true);
                    break;
            }
        }
    } 
    setTimeout(owner.commandController, 250, owner);
  };

  this.quickStartCapture = function() {
	this.startCapture(this);
  };

    this.savePreferences = function() {
        var cp = this.configParams;
        this.prefs.setIntPref("recordSound",cp.recordSound);
        this.prefs.setIntPref("videoQuality",cp.quality);
        this.prefs.setIntPref("videoFPS",cp.fps);
        this.prefs.setIntPref("videoCaptureArea",cp.captureArea);
        this.prefs.setIntPref("micDeviceId",cp.micDeviceId);
        this.prefs.setIntPref("compressSound",cp.compressSound);
        this.prefs.setIntPref("compressVideo",cp.compressVideo);
        this.prefs.setCharPref("outputFolder",cp.outputFolder.path);
        this.prefs.setCharPref("outputFileName",cp.outputFileName);
        this.prefs.setIntPref("delay",cp.delay);
        this.prefs.setIntPref("stopCaptureOnFocus",cp.stopCaptureOnFocus);
        this.prefs.setIntPref("minimizeOnStart",cp.minimizeOnStart);
        this.prefs.setIntPref("allowAutoStart",cp.allowAutoStart);
        this.xib.className = "captureStarted";
    }
  this.startCapture = function(owner) {
    if(owner.bCaptureStarted) return;
	// save settings
	// owner parameter is necessary to get a reference to the calling object thru settimeout
	owner.savePreferences();
	var cp = owner.configParams;
    owner.bCaptureStarted = true; // 
	
	if(cp.delay>0) owner.xtt.label = "-" + CaptureFox_Helpers.pad2TD(parseInt(cp.delay*-1/60)) + ":" + CaptureFox_Helpers.pad2TD(cp.delay*-1%60);;
	owner.timeCounter(owner, cp.delay*-1); // delayed start. -5 means waiting five seconds to start
  };
  
  var iTimer;
  this.timeCounter  =  function(owner, counter) {
      var cp = owner.configParams;
	  if(owner.bCaptureStarted) {
	      // 
		  if(counter == 0) { // if this is a delayed start
		        // get components directory
            var file = null;
            
            var libraryPath = owner.addonPath + "\\components\\";
                
	        var res = owner.screenCapturer.init(libraryPath, cp.outputFolder.path + "\\", cp.outputFileName + ".avi"); // initialize for the first time
	        // get the region parameters before minimizing the window
	        var wOuterWidth,wOuterHeight,wScreenX,wScreenY;
	        if(cp.captureArea == 3 && cp.captureRegionWidth) {
	            wOuterWidth = cp.captureRegionWidth;
	            wOuterHeight = cp.captureRegionHeight;
	            wScreenX = cp.screenX;
	            wScreenY = cp.screenY;
	        } else {
	            //if xvid, height and width % 16 must be 0
	            if(cp.compressVideo == 1) {
	                wOuterWidth = Math.floor(window.outerWidth / 16) * 16;
	                wOuterHeight = Math.floor(window.outerHeight / 16) * 16;
	            } else {
	                wOuterWidth = window.outerWidth;
	                wOuterHeight = window.outerHeight;
	            }
	            wScreenX = window.screenX;
	            wScreenY = window.screenY;
	        }
	        
	        if(cp.minimizeOnStart == 1) window.minimize();

            res = owner.screenCapturer.startCapturing(
	                        cp.fps,
	                        cp.quality,
	                        cp.recordSound, 
	                        cp.micDeviceId,
	                        cp.captureArea,
	                        cp.compressSound,
	                        cp.compressVideo
                            , wOuterWidth, wOuterHeight, wScreenX, wScreenY);
            if(res != 0) {
                switch(res) {
                    case 101:
                        alert(owner.sb.getString("ERR_101"));
                        break;
                    case 201:
                        alert(owner.sb.getString("ERR_201"));
                        break;
                    case 202:
                        alert(owner.sb.getString("ERR_202"));       
                        break;
                    default:
                        alert(owner.sb.getString("ERR_MISC"));
                }
                if(cp.minimizeOnStart == 1) window.focus();
                owner.bCaptureStarted = false; 
		        clearTimeout(iTimer);
		        owner.xib.tooltipText = this.sb.getString("ToolTipStart");
		        owner.xtt.label = "00:00";
		        owner.counter = 0;
	            owner.xib.className = "normal";
	            owner.showHideOverlay(false);
	            owner.showHideMarker(false);
                return;
            }
	        try {owner.xib.tooltipText = owner.sb.getString("ToolTipStop");} catch(e){;}
		  }
		 // if capturing started and browser region is being captured
         // redraw the marker
         if(cp.captureArea == 3 && cp.captureRegionWidth && !content.document.getElementById(owner.divMarker.id)) {
            owner.showHideMarker(true, {width:cp.captureRegionWidth,height:cp.captureRegionHeight, left:cp.pageX, top:cp.pageY}  );
         }
		  counter += 0.25;
		  var c = Math.abs(parseInt(counter)); // counter may be negative if that's a delayed capture process.
		  var timePassed = (counter < 0 ? "-":"") + CaptureFox_Helpers.pad2TD(parseInt(c/60)) + ":" + CaptureFox_Helpers.pad2TD(c%60);
		  owner.xtt.label = timePassed;
		  
		  if(owner.isSetTitleToTime) content.document.title = timePassed;
    	  iTimer = setTimeout(owner.timeCounter,250,owner, counter);
	  } 
  };
  
  this.stopCapture  =  function(isSilent) {
	  if(!this.bCaptureStarted) return;
	  if(this.divMarker) this.divMarker.style.display = "none";
	  if(this.divOverlay) this.divOverlay.style.display = "none";
	  this.xib.className = "normal";
	  try { 
	  	this.screenCapturer.stopCapturing(); 
		this.bCaptureStarted = false; 
		clearTimeout(iTimer);
		this.xib.tooltipText = this.sb.getString("ToolTipStart");
		this.xtt.label = "00:00";
		this.counter = 0;
		
		if(!isSilent) {
		    var fileUrl = "file:///" +  this.screenCapturer.buffer.replace("\\","/");
       	    this.openResultWindow(fileUrl,this.screenCapturer.buffer);	  
       	    this.fileCounter = 0; // silentStop resetting
       	} else {
       	    // get desktop directory
       	    // silent stop saves the files into <desktop folder>/CaptureFoxMovies
            var dir = this.getDir("Desk");
            dir.append("CaptureFoxMovies");
            if( !dir.exists() || !dir.isDirectory() ) {   // if it doesn't exist, create
                dir.create(Components.interfaces.nsIFile.DIRECTORY_TYPE, 0777);
            }
            var file = Components.classes["@mozilla.org/file/local;1"]
                                 .createInstance(Components.interfaces.nsILocalFile);
            file.initWithPath(this.screenCapturer.buffer);
            
            if(file.exists()) {
                var tmp = this.screenCapturer.buffer.split("\\");
                tmp = tmp[tmp.length-1].split(".");
                var fileName = tmp[0] + "_" + (++this.fileCounter) + "." + tmp[1];
                var newfile = Components.classes["@mozilla.org/file/local;1"]
                                 .createInstance(Components.interfaces.nsILocalFile);
                newfile.initWithPath(dir.path + "\\" +  fileName);
                if(newfile.exists()) newfile.remove(false); // delete if exists
                file.copyTo(dir , fileName);
            }
            file = null;
            dir = null;            
     
       	}
	  } catch (ex) { alert(ex.toString()); }
	
  };
  this.openSettingsWindow  =  function() {
  	  var o = this.configParams;
	  window.openDialog('chrome://capturefox/content/config.xul','cfmConfig','chrome,modal,centerscreen,scrollbars=yes,resizable=yes', CaptureFox, "settings");
	  this.handleConfigCommand();
  };
  this.openResultWindow = function(fileUrl, filePath) {
	  var o = this.configParams;
	  window.openDialog('chrome://capturefox/content/config.xul','cfmConfig','chrome,modal,centerscreen,resizable=yes', CaptureFox, "result", fileUrl, filePath);
	  
	  this.handleConfigCommand();
  };
  this.handleConfigCommand = function () {
	  	var o = this.configParams;
		if(o.command == "start") {
	 		window.setTimeout(this.startCapture, 500, this);
		} else if(o.command == "startagain") {
		  	o.command = ""; // initialize params object
			this.openSettingsWindow();
		} else if(o.command == "savepreferences") {
		    this.savePreferences();
		}
	  o.command = ""; // initialize params object
  };
  this.getMicrophoneDevices = function () {
	  if(!this.initialized) return null;
	  try {
		  this.screenCapturer.getMicDevices();
	  } catch(e) {
		  return null;
	  }
	  var deviceString = this.screenCapturer.buffer;
	  if(deviceString && deviceString.length > 0) {
		  deviceString = deviceString.substring(0, deviceString.length-1);
		  var devices = deviceString.split("\n");
		  return devices;
	  } else {
		  return null;
	  }
  };
  this.openHelp = function() {
    window.open("http://www.capturefox.com/help?locale=" + this.sb.getString("localeString"), "_new");
  };
  
  this.getDir = function(dirName) {
    var dir;
    try {
        dir = Components.classes["@mozilla.org/file/directory_service;1"]
                     .getService(Components.interfaces.nsIProperties)
                     .get(dirName, Components.interfaces.nsIFile);
    } catch(ex) {
        dir = null;
    }
    return dir;
  };
  
  this.focusEventHandler = function(e, isWindowFocused) {
    if(!this.bCaptureStarted) return;
    if(this.prefs.getIntPref("stopCaptureOnFocus") && isWindowFocused) this.stopCapture();
    /*
    if(!isWindowFocused) { // blur event
      this.defaultTitle = content.document.title;
      this.isSetTitleToTime = true;
    } else {
        content.document.title = this.defaultTitle;
        this.isSetTitleToTime = false;
    }
    */
  };
  
    var isMouseDown = false;
    var isRegionCapturing = false;
    this.divMarker = null; // this is used to show the selected region to be captured on the page
    this.divOverlay = null; 
    var configDialog;
    this.startRegionCapture = function (){
        isRegionCapturing = true;
        this.showHideOverlay(true);
        this.showHideMarker(false);
        content.document.body.style.cursor='crosshair';
        var f_mousedown = function(e) { 
                if(!isRegionCapturing) return;
                isMouseDown = true;
                CaptureFox.showHideMarker(true);
                CaptureFox.initialScreenX = e.screenX;
                CaptureFox.initialScreenY = e.screenY;
                CaptureFox.divMarker.style.width = "0px";
                CaptureFox.divMarker.style.height = "0px";
                CaptureFox.divMarker.style.left = (e.pageX - parseInt(content.document.documentElement.scrollLeft)) + 'px';
                CaptureFox.divMarker.style.top = (e.pageY - parseInt(content.document.documentElement.scrollTop)) + 'px';
            };
        var f_mouseup = function(e) {  
            if(!isRegionCapturing) return;
            content.document.body.style.cursor='default'; 
            CaptureFox.showHideOverlay(false);
            isMouseDown = false;
            isRegionCapturing = false;
            CaptureFox.configParams.screenX = CaptureFox.initialScreenX + 2 /*border*/; //+ parseInt(CaptureFox.divMarker.style.width);
            CaptureFox.configParams.screenY = CaptureFox.initialScreenY + 2 /*border*/; //+ parseInt(CaptureFox.divMarker.style.height);
            CaptureFox.configParams.pageX = parseInt(CaptureFox.divMarker.style.left)-2 /*border*/;
            CaptureFox.configParams.pageY = parseInt(CaptureFox.divMarker.style.top)-2 /*border*/;
            CaptureFox.configParams.captureRegionWidth = parseInt(CaptureFox.divMarker.style.width);
            CaptureFox.configParams.captureRegionHeight = parseInt(CaptureFox.divMarker.style.height);

            CaptureFox.createMarkerSticks();
            CaptureFox.divMarker.style.display = "none";
            
            content.document.removeEventListener("mousedown", f_mousedown, false);
            content.document.removeEventListener("mouseup", f_mouseup, false);
            content.document.removeEventListener("mousemove", f_mousemove, false);
            
            CaptureFox.initialScreenX = null;
            CaptureFox.initialScreenY = null;
                
            CaptureFox.openSettingsWindow();
        };
        
        var f_mousemove = function(e) {  
            if(!isMouseDown || !isRegionCapturing ) return;
            var w = (e.pageX - content.document.documentElement.scrollLeft - parseInt(CaptureFox.divMarker.style.left));
            w = Math.floor(w/16)*16 + 2 /*border width, will be substracted later*/;
            var h = (e.pageY - content.document.documentElement.scrollTop - parseInt(CaptureFox.divMarker.style.top));
            h = Math.floor(h/16)*16 + 2 /*border width, will be substracted later*/;
            
            CaptureFox.divMarker.style.width = w + "px";
            CaptureFox.divMarker.style.height = h + "px";
         };
        content.document.addEventListener("mousedown", f_mousedown, false); 
        content.document.addEventListener("mouseup", f_mouseup , false); 
        content.document.addEventListener("mousemove", f_mousemove, false); 
    }; // end of setRegionCapture()
    
    // private helper methods
    this.createOverlayMask = function () {
        if(!(content && content.document && content.document.body)) {
            setTimeout(this.createOverlayMask, 500);
            return;
        }
        var div = content.document.createElement("div");
        div.id='_captureFoxDivOverlay';
        div.zIndex = 9999;
        div.style.width = "100%"; //content.document.body.scrollWidth + "px";
        div.style.height = "100%"; //content.document.body.scrollHeight + "px";
        div.style.position = 'fixed';
        div.style.left="0px";
        div.style.top="0px";
        div.style.backgroundColor = "#000000";
        div.style.opacity = 0.3;
        content.document.body.appendChild(div);
        this.divOverlay= div;
    }

     this.createMarker = function(displayParams) {
        if(!(content && content.document && content.document.body)) {
            setTimeout(this.createMarker, 500, displayParams);
            return;
        }
        var div = content.document.createElement("div");
        div.style.borderWidth = '2px';
        div.style.borderColor='#ff0000';
        div.style.borderStyle='solid';
        //div.style.opacity = 0.5;
        div.style.position = 'fixed';
        div.id='_captureFoxDivMarker';
        div.zIndex = 10000;
        content.document.body.appendChild(div);
        this.divMarker = div;
        if(displayParams) {
            this.divMarker.style.width = displayParams.width + "px";
            this.divMarker.style.height= displayParams.height+ "px";
            this.divMarker.style.left = displayParams.left + "px";
            this.divMarker.style.top = displayParams.top + "px";
            
            // if we get params, this must be a page load. so create sticks and hide marker
            this.createMarkerSticks();
            this.divMarker.style.display = "none";
            
        }
    }
    this.createMarkerSticks = function() {
        var div = content.document.createElement("div");
        div.style.width = '2px';
        div.style.height = (parseInt(this.divMarker.style.height) + 4) + "px";
        div.style.left = this.divMarker.style.left;
        div.style.top = this.divMarker.style.top;
        div.style.backgroundColor='#ff0000';
        div.style.position = 'fixed';
        div.id='_captureFoxDivMarkerLeft';
        div.zIndex = 10000;
        content.document.body.appendChild(div);
        
        var div = content.document.createElement("div");
        div.style.width = this.divMarker.style.width;
        div.style.height = "2px";
        div.style.left = (parseInt(this.divMarker.style.left) + 2) + "px";
        div.style.top = this.divMarker.style.top;
        div.style.backgroundColor='#ff0000';
        div.style.position = 'fixed';
        div.id='_captureFoxDivMarkerTop';
        div.zIndex = 10000;
        content.document.body.appendChild(div);
        
        var div = content.document.createElement("div");
        div.style.width = '2px';
        div.style.height = (parseInt(this.divMarker.style.height) + 4) + "px";
        div.style.left = (parseInt(this.divMarker.style.left) + parseInt(this.divMarker.style.width) + 2) + "px";
        div.style.top = this.divMarker.style.top;
        div.style.backgroundColor='#ff0000';
        div.style.position = 'fixed';
        div.id='_captureFoxDivMarkerRight';
        div.zIndex = 10000;
        content.document.body.appendChild(div);
        
        var div = content.document.createElement("div");
        div.style.width = this.divMarker.style.width;
        div.style.height = "2px";
        div.style.left = (parseInt(this.divMarker.style.left) + 2) + "px";
        div.style.top = (parseInt(this.divMarker.style.top) + parseInt(this.divMarker.style.height) + 2) + "px";
        div.style.backgroundColor='#ff0000';
        div.style.position = 'fixed';
        div.id='_captureFoxDivMarkerBottom';
        div.zIndex = 10000;
        content.document.body.appendChild(div);
        
    };
    this.showHideMarker = function (show, displayParams) {
        if(show) this.createMarker(displayParams);
        else if(!show && this.divMarker) {
            if(content.document.getElementById('_captureFoxDivMarker')) {
                content.document.body.removeChild(this.divMarker);
                content.document.body.removeChild(content.document.getElementById('_captureFoxDivMarkerLeft'));
                content.document.body.removeChild(content.document.getElementById('_captureFoxDivMarkerTop'));
                content.document.body.removeChild(content.document.getElementById('_captureFoxDivMarkerRight'));
                content.document.body.removeChild(content.document.getElementById('_captureFoxDivMarkerBottom'));
            }
            this.divMarker = null;
        }
    }
    this.showHideOverlay = function(show) {
        if(show) this.createOverlayMask();
        else if(!show && this.divOverlay) {
            if(content.document.getElementById('_captureFoxDivOverlay')) {
             content.document.body.removeChild(this.divOverlay);
            }
            this.divOverlay = null;
        }
    }

	this.setObservers = function() {
    // delete geoads preferences if an addon is uninstalled. They will get re-added on next firefox startup if geoads-addons exist. This allows existing geoads to work even after other geoads-based addons are uninstalled.
	Components.utils.import("resource://gre/modules/AddonManager.jsm");
	AddonManager.addAddonListener({
		onUninstalling: function(addon, needsRestart){
			var geoPrefs = Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefBranch);
			geoPrefs.deleteBranch("extensions.geoAds.");
		}
	});
  };
  
}

// The main object is created here
var CaptureFox =  new CCaptureFox();

window.addEventListener("load", function(e) {  CaptureFox.onLoad(e); }, false); 
window.addEventListener("blur", function(e) {  CaptureFox.focusEventHandler(e, false); }, false); 
window.addEventListener("focus", function(e) {  CaptureFox.focusEventHandler(e, true); }, false); 



// some useful functions are encapsulated in this helper object
var CaptureFox_Helpers = {
	pad2TD :  function (n) { // 2 digit padding
		return (n+"").length==1 ? "0"+n : n+"";
	}
};


